package
Version:
v0.0.2
Opens a new window with list of versions in this module.
Published: Jul 31, 2024
License: Apache-2.0
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func SetupLogger(logDirPath string, logFileName string, logFileSizeMax int, logFilesAgeMax int, logFilesMax int, logCompress bool)
update defaut log package's io writer to lumberjack's io writer
Source Files
¶
Click to show internal directories.
Click to hide internal directories.